This package is for my best friend “nitas”
==========================================

PyPi: https://pypi.org/project/nitasthecat/

Hello there, This package shows my cat all details i hope you enjoy.

how to install
~~~~~~~~~~~~~~

open CMD / Terminal

.. code:: python

   pip install nitasthecat

how to use this package
~~~~~~~~~~~~~~~~~~~~~~~

-  open IDLE then type…

.. code:: python

   from nitasthecat import Nitas

   cat = Nitas() 
   cat.show_name() 
   cat.about() 
   cat.show_ascii() 
   cat.show_youtube
   cat.show_IG()

developed by beamtan github: https://github.com/beamtan
